@@ -1,10 +1,10 @@
 from argparse import ArgumentParser
-from os import mkdir, path, walk
+from os import makedirs, path, walk
 from re import search
 from subprocess import PIPE, STDOUT, Popen
 from time import sleep
 
-from colorifix.colorifix import Color, Style, paint
+from colorifix.colorifix import Color, paint
 from halo import Halo
 from pymortafix.utils import multisub
 from requests import get
@@ -21,7 +21,7 @@ def last_episodes_downloaded(folder_name):
         return []
     _, _, files = tree[0]
     return [
-        int(se_ep.group(1)) for file in files if (se_ep := search(r"_Ep(\d+)", file))
+        int(se_ep.group(1)) for file in files if (se_ep := search(r"_s\d+e(\d+)", file))
     ]
 
 
@@ -29,88 +29,52 @@ def sanitize_name(name):
     return multisub({":": "", " ": "_"}, name)
 
 
-def download_mp4(url, name, ep, folder):
-    basepath = path.join(CONFIG.get("path"), folder)
-    if not path.exists(basepath):
-        mkdir(basepath)
-    filename = path.join(basepath, f"{sanitize_name(name)}_Ep{ep}.mp4")
+def download_mp4(url, name, filename):
     chunk_size = 8192
     with get(url, stream=True) as r:
         r.raise_for_status()
-        size = int(r.headers.get("Content-Length"))
         with open(filename, "wb") as f:
             downloaded = 0
             for chunk in r.iter_content(chunk_size=chunk_size):
                 downloaded += chunk_size
-                SPINNER.start(
-                    f"Downloading {paint(name,Color.BLUE)} "
-                    f"ep {paint(ep,Color.MAGENTA)} "
-                    f"[{paint(f'{downloaded/size*100:.1f}',style=Style.BOLD)}%]"
-                )
                 f.write(chunk)
-    SPINNER.succeed(f"Downloaded {paint(name,Color.BLUE)} ep {paint(ep,Color.MAGENTA)}")
     return filename
 
 
-def download_yt_dl(url, name, ep, folder):
-    basepath = path.join(CONFIG.get("path"), folder)
-    if not path.exists(basepath):
-        mkdir(basepath)
-    filename = path.join(basepath, f"{sanitize_name(name)}_Ep{ep}.mp4")
+def download_yt_dl(url, name, filename):
     popen = Popen(
         f"youtube-dl {url} -o '{filename}'",
         shell=True,
         stdout=PIPE,
         stderr=STDOUT,
     )
-    SPINNER.start(
-        f"Downloading {paint(name,Color.BLUE)} " f"ep {paint(ep,Color.MAGENTA)}"
-    )
     while True:
         next_line = popen.stdout.readline()
         line = next_line.rstrip().decode("utf8")
         if line == "" and popen.poll() is not None:
             break
-    SPINNER.succeed(f"Downloaded {paint(name,Color.BLUE)} ep {paint(ep,Color.MAGENTA)}")
     return filename
 
 
-def download_m3u8(url, name, ep, folder):
-    basepath = path.join(CONFIG.get("path"), folder)
-    if not path.exists(basepath):
-        mkdir(basepath)
-    filename = path.join(basepath, f"{sanitize_name(name)}_Ep{ep}.mp4")
+def download_m3u8(url, name, filename):
     popen = Popen(
         f"ffmpeg -y -i {url} '{filename}'",
         shell=True,
         stdout=PIPE,
         stderr=STDOUT,
     )
-    size, lines = 0, 0
     while True:
         next_line = popen.stdout.readline()
         line = next_line.rstrip().decode("utf8")
         if line == "" and popen.poll() is not None:
             break
-        if lines % 7:
-            size = (
-                (m := search(r"size=\s*(\d+)[a-zA-Z]{2}", line)) and m.group(1) or size
-            )
-        else:
-            SPINNER.start(
-                f"Downloading {paint(name,Color.BLUE)} "
-                f"ep {paint(ep,Color.MAGENTA)} "
-                f"[{paint(f'{int(size)/1024:.1f}',style=Style.BOLD)} MB]"
-            )
-            sleep(1)
-        lines += 1
-    SPINNER.succeed(f"Downloaded {paint(name,Color.BLUE)} ep {paint(ep,Color.MAGENTA)}")
+            sleep(2)
     return filename
 
 
 def download():
     anime_list = [list(anime.values()) for anime in CONFIG.get("anime")]
-    for name, url, folder, mode in anime_list:
+    for name, url, season, folder, mode in anime_list:
         downloaded_eps = last_episodes_downloaded(folder)
         links, eps_available = get_episodes_link(url)
         if mode == "full":
@@ -120,19 +84,33 @@ def download():
             eps_to_download = [ep for ep in eps_available if ep > last_ep_downloaded]
         for ep in eps_to_download:
             episode_link, download_link = get_download_link(links[ep - 1])
+            basepath = path.join(CONFIG.get("path"), folder, f"Stagione {season}")
+            if not path.exists(basepath):
+                makedirs(basepath)
+            filename = path.join(
+                basepath, f"{sanitize_name(name)}_s{int(season):02d}e{ep:02d}.mp4"
+            )
+            SPINNER.start(
+                f"Downloading {paint(name,Color.BLUE)} "
+                f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
+            )
             try:
                 if search("m3u8", download_link):
-                    download_m3u8(download_link, name, ep, folder)
+                    download_m3u8(download_link, name, filename)
                 if search("mp4", download_link):
-                    download_mp4(download_link, name, ep, folder)
+                    download_mp4(download_link, name, filename)
             except Exception:
                 try:
-                    download_yt_dl(episode_link, name, ep, folder)
+                    download_yt_dl(episode_link, name, filename)
                 except Exception:
                     SPINNER.fail(
                         f"Fail to download {paint(name,Color.BLUE)} "
-                        f"ep {paint(ep,Color.MAGENTA)}"
+                        f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
                     )
+            SPINNER.succeed(
+                f"Downloaded {paint(name,Color.BLUE)} "
+                f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
+            )
 
 
 def argparsing():
